pub struct ApplyFn<'a, A, B> { /* private fields */ }Expand description
An ApplyFn is a function from A to B wrapped in something Rust’s type
system can more easily digest. Arguments for
Apply::apply() are required to be of this type rather than
an arbitrary type matching Fn(A) -> B.
Implementations